==> developer-center-api-1.0.8.zhengjy-20160825.111842-8-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/CreateAppQueryParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import com.google.common.base.Joiner;
import com.google.common.base.Objects;
import com.google.common.base.Splitter;
import org.apache.commons.lang.StringUtils;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Collections;
import java.util.List;

/**
 * Created by liuyao on 16/7/29.
 */
public class CreateAppQueryParams implements Serializable{
    private static final long serialVersionUID = -7512381957793791622L;

    @NotNull(message = "创建App必须指定开发者")
    private Long developerId;
    @NotNull(message = "App名称不能为空")
    private String name;
    @NotNull(message = "积分汇率不能为空")
    @Min(value = 1,message = "积分汇率必须大于0")
    private Integer creditsRate = 100;
    @NotNull(message = "积分名称不能为空")
    private String unitName;
    @NotNull(message = "必须指定应用类别")
    private String category;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getCreditsRate() {
        return creditsRate;
    }

    public void setCreditsRate(Integer creditsRate) {
        this.creditsRate = creditsRate;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public List<String> getCategory(){
        if(StringUtils.isBlank(category)){
            return Collections.emptyList();
        }
        Splitter spl = Splitter.on(",").limit(2).trimResults().omitEmptyStrings();
        return spl.splitToList(category);
    }

    public void setCategory(String ...category) {
        if(category.length>2){
            throw new RuntimeException("应用类别层级最多为两级");
        }
        Joiner joiner = Joiner.on(",").skipNulls();
        this.category = joiner.join(category);
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

}

==> developer-center-api-1.3.4-zhengjy5.20161115.065319-1-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/CreateAppQueryParams.java <==
package cn.com.duiba.developer.center.api.domain.paramquery;

import cn.com.duiba.service.exception.BusinessException;
import com.google.common.base.Joiner;
import com.google.common.base.Objects;
import com.google.common.base.Splitter;
import org.apache.commons.lang.StringUtils;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Collections;
import java.util.List;

/**
 * Created by liuyao on 16/7/29.
 */
public class CreateAppQueryParams implements Serializable{
    private static final long serialVersionUID = -7512381957793791622L;

    public final static Integer CREATE_SOURCE_CREDITS = 0;//商城
    public final static Integer CREATE_SOURCE_AD = 1;//广告

    @NotNull(message = "创建App必须指定开发者")
    private Long developerId;
    @NotNull(message = "App名称不能为空")
    @Size(max = 20,min = 1,message = "App名称最长为20个字符")
    private String name;
    @NotNull(message = "积分汇率不能为空")
    @Min(value = 1,message = "积分汇率必须大于0")
    private Integer creditsRate = 100;
    @NotNull(message = "积分名称不能为空")
    @Size(max = 15,min = 1,message = "积分单位最长15个字符")
    private String unitName = "积分";
    @NotNull(message = "必须指定应用类别")
    private String category = "工具";

    @NotNull(message = "必须指定创建的来源")
    private Integer createSource = CREATE_SOURCE_CREDITS;

    @NotNull
    private Boolean mallCredits = false;//false代表积分商城模式,true代表无积分模式

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getCreditsRate() {
        return creditsRate;
    }

    public void setCreditsRate(Integer creditsRate) {
        this.creditsRate = creditsRate;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public List<String> getCategory(){
        if(StringUtils.isBlank(category)){
            return Collections.emptyList();
        }
        Splitter spl = Splitter.on(",").limit(2).trimResults().omitEmptyStrings();
        return spl.splitToList(category);
    }

    public void setCategory(String ...category) throws BusinessException {
        if(category.length>2){
            throw new BusinessException("应用类别层级最多为两级");
        }
        Joiner joiner = Joiner.on(",").skipNulls();
        this.category = joiner.join(category);
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public Boolean getMallCredits() {
        return mallCredits;
    }

    public void setMallCredits(Boolean mallCredits) {
        this.mallCredits = mallCredits;
    }

    public Integer getCreateSource() {
        return createSource;
    }

    public void setCreateSource(Integer createSource) {
        this.createSource = createSource;
    }

}
